[![PyPI version](https://badge.fury.io/py/seqexplainer.svg)](https://badge.fury.io/py/motifdata)

<img src="docs/_static/MotifData_logo.png" alt="MotifData Logo" width=350>

# MotifData - Motif analysis toolkit in Python

```python
import motifdata as motif
```

### Motif analysis with [MotifData](https://github.com/ML4GLand/MotifData)

  - Perform HOMER motif analysis
  - Perform MEME motif analysis
  - Perform DEM (Cluster-buster based) motif analysis
  - Perform cisTarget